==> qtwebengine-everywhere-src-5.10.1.tar.xz: qtwebengine-everywhere-src-5.10.1/src/3rdparty/chromium/docs/speed/README.md <==
# Chrome Speed

## Contact information

  * **Contact**: **speed@chromium.org**
  * **Escalation**:
    * benhenry@chromium.org (TPM)
    * rschoen@chromium.org (PM)
    * parisa@chromium.org (eng director)
  * **File a bug**: [template](https://bugs.chromium.org/p/chromium/issues/entry?template=Speed%20Bug)
  * **Regression postmortem**: [template](https://docs.google.com/document/d/1fvfhFNOoUL9rB0XAEe1MYefyM_9yriR1IPjdxdm7PaQ/edit?disco=AAAABKdHwCg)

## User Docs

  * [How does Chrome measure performance?](how_does_chrome_measure_performance.md)
  * [My CL caused a performance regression! What do I do?](addressing_performance_regressions.md)
  * [I want Chrome to have better performance](help_improve_performance.md)
  * [Perf sheriffing documentation](perf_regression_sheriffing.md)
  * [I want to add tests or platforms to the perf waterfall](adding_tests_bots.md)

## Core Teams and Work

  * **[Speed tracks](speed_tracks.md)**: Most of the speed 
    work on Chrome is organized into these tracks.
  * **[Chrome Speed Operations](chrome_speed_operations.md)**: provides the
    benchmarks, infrastructure, and releasing oversight to track regressions.
    <!--- TODO: General discussion: chrome-speed-operations mailing list link -->
    <!--- TODO: Tracking releases and regressions: chrome-speed-releasing mailing list link -->
    * Benchmark-specific discussion: benchmarking-dev@chromium.org
    <!--- TODO: Requests for new benchmarks: chrome-benchmarking-request mailing list link -->
    * Performance dashboard, bisect, try jobs: speed-services-dev@chromium.org
  * **[Chrome Speed Metrics](https://docs.google.com/document/d/1wBT5fauGf8bqW2Wcg2A5Z-3_ZvgPhE8fbp1Xe6xfGRs/edit#heading=h.8ieoiiwdknwt)**: provides a set of high-quality metrics that represent real-world user experience, and exposes these metrics to both Chrome and Web Developers.
    * General discussion: progressive-web-metrics@chromium.org
    * The actual metrics: [tracking](https://docs.google.com/spreadsheets/d/1gY5hkKPp8RNVqmOw1d-bo-f9EXLqtq4wa3Z7Q8Ek9Tk/edit#gid=0)

==> qtwebengine-everywhere-src-5.15.0.tar.xz: qtwebengine-everywhere-src-5.15.0/src/3rdparty/chromium/docs/speed/README.md <==
# Chrome Speed

## Contact information

  * **Contact**: **speed@chromium.org**
  * **Escalation**:
    * benhenry@chromium.org (TPM)
  * **File a bug**: [template](https://bugs.chromium.org/p/chromium/issues/entry?template=Speed%20Bug)
  * **Regression postmortem**: [template](https://docs.google.com/document/d/1fvfhFNOoUL9rB0XAEe1MYefyM_9yriR1IPjdxdm7PaQ/edit?disco=AAAABKdHwCg)

## User Docs

  * [How does Chrome measure performance?](how_does_chrome_measure_performance.md)
  * [My CL caused a performance regression! What do I do?](addressing_performance_regressions.md)
  * [I want Chrome to have better performance](help_improve_performance.md)
  * [Perf sheriffing documentation](perf_regression_sheriffing.md)
  * [I want to add tests or platforms to the perf waterfall](adding_tests_bots.md)

## Core Teams and Work

  * **[Speed domain area experts](speed_domains.md)**: These mailing lists and
    bug triage rotations provide expertise into specific domain areas of Speed:
    memory, power, loading, responsiveness, binary size, data usage, and browser
    UI.
  * **[Chrome Speed Operations](chrome_speed_operations.md)**: provides the
    benchmarks, infrastructure, and releasing oversight to track regressions.
    <!--- TODO: General discussion: chrome-speed-operations mailing list link -->
    <!--- TODO: Tracking releases and regressions: chrome-speed-releasing mailing list link -->
    * Benchmark-specific discussion: benchmarking-dev@chromium.org
    <!--- TODO: Requests for new benchmarks: chrome-benchmarking-request mailing list link -->
    * Performance dashboard, bisect, try jobs: speed-services-dev@chromium.org
  * **Chrome Speed Metrics**: provides a set of high-quality metrics that represent real-world user experience, and exposes these metrics to both Chrome and Web Developers.
    * General discussion: speed-metrics-dev@chromium.org
    * The actual metrics: [speed launch metrics survey.](https://docs.google.com/document/d/1Ww487ZskJ-xBmJGwPO-XPz_QcJvw-kSNffm0nPhVpj8/edit#heading=h.2uunmi119swk)
